@@ -9,17 +9,23 @@
 typedef struct ITEXT{
 	unsigned int c1;
 	unsigned int c2;
-
 	char *utf8;
 
+	char *chu_string;
+
 	int x_off;
 	int y_off;
 
 	int ej;
 	int chu;
+	int rub;
+	int jis;
+	int tes;
+
 	int bouten;
 	int small;
 
+
 	struct ITEXT *rubi_head;
 	struct ITEXT *rubi_tail;
 
@@ -46,19 +52,25 @@ typedef struct BOOKFILEDATA{
         int size;
         int code;
 
+	unsigned long fno;
+
         struct BOOKFILEDATA *next;
         struct BOOKFILEDATA *prev;
 }IBOOK_T;
+typedef struct BOUTENDATA{
+	char *name;
+	unsigned int c1;
+	unsigned int c2;
+}BOUTEN_T;
+
 
 int ibookGetFileData(IBOOK_T **,IBOOK_T **,char *);
-
-void book_link_free(IBOOK_T **,IBOOK_T **);
-
 int itextGetTextData(char *,char *,IBUF_T **,IBUF_T **,int);
-
-int _checkFileType(char *);
-
+int itextDataInsert(ITEXT_T **,ITEXT_T **,unsigned int ,unsigned int,int,int,int,iconv_t);
+int checkRubyString(iconv_t,unsigned char *,int,ITEXT_T **,ITEXT_T **,int *);
 int itextUnZipFile(char *,char *);
-
+void itext_data_free(ITEXT_T *);
+void book_link_free(IBOOK_T **,IBOOK_T **);
+int _checkFileType(char *);
 char * euc2utf8(iconv_t,char *,int);
 
